﻿        <#
        ActiveX control logging setup script for WMI.

        .USAGE
            Powershell needs to be run elevated.
            To run this script by by-passing execution policy please use:
                powershell -ExecutionPolicy Bypass .\ConfigureWMILogging.ps1

            NOTE: To ensure information is logged to WMI, please enable the "Turn on ActiveX
                  control logging in Internet Explorer" Group Policy setting.
                  To disable WMI logging, disable the Group Policy setting.

            For additional information on the feature:
                https://msdn.microsoft.com/en-us/library/dn761713.aspx
        #>

Try
{
    $namespace = Get-WMIObject -namespace root/cimv2 -class __Namespace -filter "name='IETelemetry'"
}
Catch [system.exception]
{
}
Finally
{
    Try
    {
        $path = Split-Path $MyInvocation.MyCommand.Path
        $empty = mofcomp.exe $path\ActiveXWMILogging.mof

        if(!$namespace)
        {
            $SDDL = "A;;CCLCSWRPWP;;;AU"
            $security = Get-WmiObject -Namespace root/cimv2/IETelemetry -Class __SystemSecurity
            $converter = new-object system.management.ManagementClass Win32_SecurityDescriptorHelper
            $binarySD = @($null)
            $result = $security.PsBase.InvokeMethod("GetSD",$binarySD)
            $outsddl = $converter.BinarySDToSDDL($binarySD[0])
            $newSDDL = $outsddl.SDDL += "(" + $SDDL + ")"
            $WMIbinarySD = $converter.SDDLToBinarySD($newSDDL)
            $WMIconvertedPermissions = ,$WMIbinarySD.BinarySD
            $result = $security.PsBase.InvokeMethod("SetSD",$WMIconvertedPermissions)
            echo "IETelemetry namespace created."
        }

        echo "ActiveX control logging setup completed."
    }
    Catch
    {
        write-host "Caught an exception:" -ForegroundColor Red
        write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
        write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
    }
}
